# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class HmacAlgorithmEnum(str, Enum):
    """
    * `sha1` - SHA1 * `sha256` - SHA256 * `sha512` - SHA512
    """

    """
    allowed enum values
    """
    SHA1 = 'sha1'
    SHA256 = 'sha256'
    SHA512 = 'sha512'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of HmacAlgorithmEnum from a JSON string"""
        return cls(json.loads(json_str))


