# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ActionTypeEnum(str, Enum):
    """
    * `app_action` - App Action * `user_action` - User Action * `table_action` - Table Action * `trigger_action` - Trigger Action * `webhook_action` - Webhook Action
    """

    """
    allowed enum values
    """
    APP_ACTION = 'app_action'
    USER_ACTION = 'user_action'
    TABLE_ACTION = 'table_action'
    TRIGGER_ACTION = 'trigger_action'
    WEBHOOK_ACTION = 'webhook_action'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ActionTypeEnum from a JSON string"""
        return cls(json.loads(json_str))


