# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.invoke_parallel_call_for_connection_request import InvokeParallelCallForConnectionRequest

class TestInvokeParallelCallForConnectionRequest(unittest.TestCase):
    """InvokeParallelCallForConnectionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvokeParallelCallForConnectionRequest:
        """Test InvokeParallelCallForConnectionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvokeParallelCallForConnectionRequest`
        """
        model = InvokeParallelCallForConnectionRequest()
        if include_optional:
            return InvokeParallelCallForConnectionRequest(
                method = 'GET',
                endpoint = '',
                data_list = [
                    robotnikai.models.invoke_parallel_call_for_connection_request_data_list_inner.invoke_parallel_call_for_connection_request_data_list_inner(
                        params = robotnikai.models.params.params(), 
                        data = robotnikai.models.data.data(), 
                        url_params = robotnikai.models.url_params.url_params(), )
                    ],
                request_headers = None,
                streaming = True
            )
        else:
            return InvokeParallelCallForConnectionRequest(
                method = 'GET',
                data_list = [
                    robotnikai.models.invoke_parallel_call_for_connection_request_data_list_inner.invoke_parallel_call_for_connection_request_data_list_inner(
                        params = robotnikai.models.params.params(), 
                        data = robotnikai.models.data.data(), 
                        url_params = robotnikai.models.url_params.url_params(), )
                    ],
                request_headers = None,
        )
        """

    def testInvokeParallelCallForConnectionRequest(self):
        """Test InvokeParallelCallForConnectionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
