# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.applications_tables_graph_ql_api import ApplicationsTablesGraphQLApi


class TestApplicationsTablesGraphQLApi(unittest.TestCase):
    """ApplicationsTablesGraphQLApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsTablesGraphQLApi()

    def tearDown(self) -> None:
        pass

    def test_apps_graphql_playground(self) -> None:
        """Test case for apps_graphql_playground

        GraphQL Playground Interface
        """
        pass

    def test_apps_graphql_query(self) -> None:
        """Test case for apps_graphql_query

        Execute GraphQL Query/Mutation
        """
        pass


if __name__ == '__main__':
    unittest.main()
