# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.plugin_integration import PluginIntegration

class TestPluginIntegration(unittest.TestCase):
    """PluginIntegration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PluginIntegration:
        """Test PluginIntegration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PluginIntegration`
        """
        model = PluginIntegration()
        if include_optional:
            return PluginIntegration(
                name = '',
                icon = '',
                integration_id = ''
            )
        else:
            return PluginIntegration(
        )
        """

    def testPluginIntegration(self):
        """Test PluginIntegration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
