# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.integrations_email_service_api import IntegrationsEmailServiceApi


class TestIntegrationsEmailServiceApi(unittest.TestCase):
    """IntegrationsEmailServiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntegrationsEmailServiceApi()

    def tearDown(self) -> None:
        pass

    def test_integrations_mailer_notify_me_create(self) -> None:
        """Test case for integrations_mailer_notify_me_create

        Send notification email
        """
        pass


if __name__ == '__main__':
    unittest.main()
