# coding: utf-8

"""
    Automio API

    Documentation of API endpoints of Automio for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from automio.models.action_type_enum import ActionTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class Action(BaseModel):
    """
    Action
    """ # noqa: E501
    id: Optional[StrictInt] = None
    is_mine: Optional[StrictBool] = None
    table_name: Optional[StrictStr] = None
    can_view_code: Optional[StrictBool] = None
    action_type: Optional[ActionTypeEnum] = None
    name: Annotated[str, Field(strict=True, max_length=255)]
    slug: Optional[Annotated[str, Field(strict=True)]] = None
    description: Optional[StrictStr] = None
    required_confirmation: Optional[StrictBool] = None
    code: Optional[StrictStr] = None
    input_schema: Optional[Any] = None
    is_public: Optional[StrictBool] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    organization: Optional[StrictInt] = None
    table: Optional[StrictInt] = None
    app: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["id", "is_mine", "table_name", "can_view_code", "action_type", "name", "slug", "description", "required_confirmation", "code", "input_schema", "is_public", "created_at", "updated_at", "organization", "table", "app"]

    @field_validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Action from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "is_mine",
            "table_name",
            "can_view_code",
            "slug",
            "created_at",
            "updated_at",
            "organization",
            "table",
            "app",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if table_name (nullable) is None
        # and model_fields_set contains the field
        if self.table_name is None and "table_name" in self.model_fields_set:
            _dict['table_name'] = None

        # set to None if input_schema (nullable) is None
        # and model_fields_set contains the field
        if self.input_schema is None and "input_schema" in self.model_fields_set:
            _dict['input_schema'] = None

        # set to None if table (nullable) is None
        # and model_fields_set contains the field
        if self.table is None and "table" in self.model_fields_set:
            _dict['table'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Action from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "is_mine": obj.get("is_mine"),
            "table_name": obj.get("table_name"),
            "can_view_code": obj.get("can_view_code"),
            "action_type": obj.get("action_type"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "description": obj.get("description"),
            "required_confirmation": obj.get("required_confirmation"),
            "code": obj.get("code"),
            "input_schema": obj.get("input_schema"),
            "is_public": obj.get("is_public"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "organization": obj.get("organization"),
            "table": obj.get("table"),
            "app": obj.get("app")
        })
        return _obj


