# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.api.actions_api import ActionsApi


class TestActionsApi(unittest.TestCase):
    """ActionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ActionsApi()

    def tearDown(self) -> None:
        pass

    def test_actions_list(self) -> None:
        """Test case for actions_list

        List available actions
        """
        pass

    def test_actions_run_code_stream(self) -> None:
        """Test case for actions_run_code_stream

        Stream action run logs (SSE)
        """
        pass

    def test_actions_run_create(self) -> None:
        """Test case for actions_run_create

        Run an action
        """
        pass

    def test_actions_runs_status_retrieve(self) -> None:
        """Test case for actions_runs_status_retrieve

        Get action run status
        """
        pass


if __name__ == '__main__':
    unittest.main()
